﻿//   Copyright 2022 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at

//       http://www.apache.org/licenses/LICENSE-2.0

//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License. 
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using ArcGIS.Core.CIM;
using ArcGIS.Core.Data;
using ArcGIS.Core.Geometry;
using ArcGIS.Desktop.Catalog;
using ArcGIS.Desktop.Core;
using ArcGIS.Desktop.Editing;
using ArcGIS.Desktop.Extensions;
using ArcGIS.Desktop.Framework;
using ArcGIS.Desktop.Framework.Contracts;
using ArcGIS.Desktop.Framework.Dialogs;
using ArcGIS.Desktop.Framework.Threading.Tasks;
using ArcGIS.Desktop.Layouts;
using ArcGIS.Desktop.Mapping;

namespace SketchTools
{
  internal class SimpleSketchTool : MapTool
  {
    public SimpleSketchTool()
    {
      IsSketchTool = true;
      SketchType = SketchGeometryType.Line;
      SketchOutputMode = SketchOutputMode.Map;
    }

    protected override Task OnToolActivateAsync(bool active)
    {
      return base.OnToolActivateAsync(active);
    }

    protected override Task<bool> OnSketchModifiedAsync()
    {
      if (Module1.ModifySketch)
      {
        // modify sketch to remove the first segment
        //
        return QueuedTask.Run(async () =>
        {
          var sketch = await GetCurrentSketchAsync();
          if (sketch is Polyline polyline)
          {
            var count = polyline.PointCount;
            if (count > 4)
            {
              // remove the first segment
              ICollection<Segment> segments = new List<Segment>();
              polyline.GetAllSegments(ref segments);

              var firstSegment = segments.First();
              segments.Remove(firstSegment);

              var shortPolyline = PolylineBuilder.CreatePolyline(segments, polyline.SpatialReference);

              await SetCurrentSketchAsync(shortPolyline);
            }
          }

          return true;
        });
      }
      else
        return base.OnSketchModifiedAsync();


      // another example of modifying the sketch


      // ensure sketch has a maximum of 4 vertices
      //
      //return QueuedTask.Run(async () =>
      //{
      //  var sketch = await GetCurrentSketchAsync();
      //  if (sketch is Polyline polyline)
      //  {
      //    var count = polyline.PointCount;
      //    if (count > 4)
      //      await FinishSketchAsync();
      //  }

      //  return true;
      //});

    }

    protected override Task<bool> OnSketchCompleteAsync(Geometry geometry)
    {
      return base.OnSketchCompleteAsync(geometry);
    }
  }
}
